@@ -165,10 +165,10 @@ def show_menu():
     options = [
         ("1", "List All Projects"),
         ("2", "Get Project Details"),
-        ("3", "Upload Data"),
+        ("3", "Upload Images (Local to App)"),
         ("4", "Export Annotations"),
         ("5", "Import Annotations"),
-        ("6", "Upload Videos Folder"),
+        ("6", "Upload Media (Local/Cloud to App)"),
         ("7", "Logout"),
         ("q", "Quit")
     ]
@@ -318,44 +318,44 @@ def handle_get_project(config):
         print(f"[red]Failed to fetch project details: {str(e)}[/red]")
         
 def show_upload_menu():
-    """Display upload options menu"""
-    print("\n+" + "-" * 50 + "+")
-    print("|" + "Upload Options".center(50) + "|")
-    print("+" + "-" * 50 + "+")
-    
+    """Display image upload options menu (local only)"""
+    print("\n+" + "-" * 52 + "+")
+    print("|" + "Upload Images (Local to App)".center(52) + "|")
+    print("+" + "-" * 52 + "+")
+
     options = [
-        ("1", "Direct Upload"),
-        ("2", "Folder-wise Project Upload"),
-        ("3", "Tag-based Upload"),
+        ("1", "Upload Images (Single/Multiple)"),
+        ("2", "Upload Image Folder (Project-wise)"),
+        ("3", "Upload with Tags (Local Images)"),
         ("b", "Back to Main Menu"),
     ]
-    
+
     for option, description in options:
-        print(f"| {option:>4} | {description:<41} |")
-    
-    print("+" + "-" * 50 + "+")
+        print(f"| {option:>4} | {description:<45} |")
+
+    print("+" + "-" * 52 + "+")
     
     return Prompt.ask("\nEnter your choice", choices=["1", "2", "3", "b"])
 
 def show_video_upload_menu():
-    """Display upload options menu"""
-    print("\n+" + "-" * 50 + "+")
-    print("|" + "Custom Video Upload Options".center(50) + "|")
-    print("+" + "-" * 50 + "+")
-    
+    """Display media upload options menu (local/cloud to app)"""
+    print("\n+" + "-" * 52 + "+")
+    print("|" + "Upload Media (Image/Video from Local/Cloud)".center(52) + "|")
+    print("+" + "-" * 52 + "+")
+
     options = [
-        ("1", "Folder-wise Upload"),
-        ("2", "Quick Upload Local"),
-        ("3", "Quick Upload Storage"),
+        ("1", "Upload Folder (Local Image/Video)"),
+        ("2", "Quick Upload (Local to App)"),
+        ("3", "Upload from Custom Storage (S3/GCP/Azure)"),
         ("b", "Back to Main Menu"),
     ]
-    
+
     for option, description in options:
-        print(f"| {option:>4} | {description:<41} |")
+        print(f"| {option:>4} | {description:<43} |")
+
+    print("+" + "-" * 52 + "+")
     
-    print("+" + "-" * 50 + "+")
-    
-    return Prompt.ask("\nEnter your choice", choices=["1" ,"2", "3", "b"])
+    return Prompt.ask("\nEnter your choice", choices=["1", "2", "3", "b"])
 
 def handle_image_uploads(config):
     """Main image upload handler"""
@@ -483,7 +483,13 @@ def handle_custom_video_uploads(config):
 
             project_id = Prompt.ask("Enter project ID")
             folder_path = Prompt.ask("Enter folder path")
+            thumbnail_path = Prompt.ask("Enter thumbnail path")
             base_filename = Prompt.ask("filter name")
+            file_type = Prompt.ask(
+                "File type", 
+                choices=["IMAGE", "VIDEO"], 
+                default="IMAGE"
+            )
 
             # Get all cloud storage buckets
             response = config.handle_request(
@@ -517,7 +523,7 @@ def handle_custom_video_uploads(config):
             print(f"[cyan]- Base Filename: {base_filename}[/cyan]")
 
             # Import and call upload function
-            register_existing_s3_files(base_url, token, bucket_id, project_id, folder_path, base_filename)
+            register_existing_s3_files(base_url, token, bucket_id, project_id, folder_path, base_filename,file_type,thumbnail_path)
             
         elif choice == "b":
             break
