@@ -160,7 +160,7 @@ def retry_request(func, progress, task_id=None, retries=10, delay=2, *args, **kw
     return None
 
 def process_folder_videos(base_url, token, project_id, folder_path, json_files):
-    """Process all videos in a folder with JSON metadata files"""
+    """Process all videos in a folder with JSON metadata files, in batches of 300"""
     # Create thumbnail folder in the parent directory
     parent_dir = os.path.dirname(folder_path)
     thumbnail_folder = os.path.join(parent_dir, "_thumbnail")
@@ -284,146 +284,177 @@ def process_folder_videos(base_url, token, project_id, folder_path, json_files):
             print(f"[red]No files were successfully processed in {folder_path}[/red]")
             return False
         
-        # Send request to server
-        progress.update(scan_task, description=f"[cyan]Sending metadata to server for folder: {folder_name}...")
-        
         # Prepare headers
         headers = {'Authorization': f'Bearer {token}'}
         
-        try:
-            # Video API endpoint
-            video_api_endpoint = f"{base_url}/uploads/entry-datas?media_type=VIDEO"
+        # Define batch size
+        BATCH_SIZE = 300
+        total_files = len(file_data_list)
+        batch_count = math.ceil(total_files / BATCH_SIZE)
+        successful_batches = 0
+        
+        print(f"[cyan]Splitting {total_files} files into {batch_count} batches of {BATCH_SIZE}[/cyan]")
+        
+        # Process files in batches of BATCH_SIZE
+        for batch_num in range(batch_count):
+            start_idx = batch_num * BATCH_SIZE
+            end_idx = min(start_idx + BATCH_SIZE, total_files)
+            current_batch = file_data_list[start_idx:end_idx]
             
-            # Remove custom metadata flag before sending to server
-            for item in file_data_list:
-                if "needs_metadata_generation" in item:
-                    del item["needs_metadata_generation"]
-                if "folder_path" in item:
-                    del item["folder_path"]
-                    
-            payload = {
-                "project_id": project_id,
-                "items": file_data_list
-            }
+            batch_description = f"Batch {batch_num+1}/{batch_count} ({start_idx+1}-{end_idx} of {total_files})"
+            print(f"[cyan]Processing {batch_description}[/cyan]")
             
-            # Use retry for the request
-            max_retries = 5
-            response_json = None
+            progress.update(scan_task, description=f"[cyan]Sending metadata to server for folder: {folder_name} - {batch_description}...")
             
-            for attempt in range(max_retries):
-                try:
-                    progress.update(scan_task, description=f"[cyan]Sending VIDEO data to server for folder: {folder_name}...")
-                    response = requests.post(video_api_endpoint, json=payload, headers=headers)
-                    response.raise_for_status()
-                    response_json = response.json()
-                    break
-                except requests.exceptions.RequestException as e:
-                    if attempt < max_retries - 1:
-                        print(f"[yellow]API request attempt {attempt + 1}/{max_retries} failed: {str(e)}. Retrying...[/yellow]")
-                        time.sleep(3)
-                    else:
-                        raise
-            
-            if not response_json:
-                print(f"[red]Failed to get response from server for folder: {folder_name}[/red]")
-                return False
-            
-            # Get batch ID
-            batch_id = response_json.get('batch_id')
-            if not batch_id:
-                print(f"[red]Batch ID not found in response for folder: {folder_name}[/red]")
-                return False
-            
-            # Add original data back to items for upload phase
-            for i, item in enumerate(response_json.get('items', [])):
-                file_name = item['file_name']
-                # Find original item data
-                original_item = next((x for x in file_data_list if x['file_name'] == file_name), None)
-                if original_item:
-                    # Add folder path back
-                    item['folder_path'] = folder_path
-                    # Add metadata json path if available
-                    if 'meta_data' in original_item:
-                        item['meta_data'] = original_item['meta_data']
-                        # Find the full path to the JSON file
-                        json_name = original_item['meta_data']
-                        json_path = None
-                        for j in json_files:
-                            if os.path.basename(j) == json_name:
-                                json_path = j
-                                break
-                        if json_path:
-                            item['json_file_path'] = json_path
-            
-            failed_files = []
-            
-            # Create upload task
-            upload_task = progress.add_task(
-                f"[cyan]Uploading files from folder: {folder_name}...",
-                total=len(response_json.get('items', [])) * 2  # *2 for main files and thumbnails
-            )
-            
-            # Process each item
-            for item in response_json.get('items', []):
-                media_id = item['media_id']
-                file_name = item['file_name']
-                folder_path = item.get('folder_path', folder_path)
+            try:
+                # Video API endpoint
+                video_api_endpoint = f"{base_url}/uploads/entry-datas?media_type=VIDEO"
                 
-                progress.update(upload_task, description=f"[cyan]Uploading {file_name}")
+                # Remove custom metadata flag before sending to server
+                batch_data = []
+                for item in current_batch:
+                    item_copy = item.copy()
+                    if "needs_metadata_generation" in item_copy:
+                        del item_copy["needs_metadata_generation"]
+                    if "folder_path" in item_copy:
+                        del item_copy["folder_path"]
+                    batch_data.append(item_copy)
+                        
+                payload = {
+                    "project_id": project_id,
+                    "items": batch_data
+                }
                 
-                # Get JSON file path if available
-                json_file_path = item.get('json_file_path', None)
-                needs_metadata_generation = not json_file_path
+                # Use retry for the request
+                max_retries = 5
+                response_json = None
                 
-                # Get presigned URLs and upload
-                success = retry_request(
-                    request_presigned_urls,
-                    progress,
-                    upload_task,
-                    media_id=media_id,
-                    file_name=file_name,
-                    token=token,
-                    folder_path=folder_path,
-                    thumbnail_folder=thumbnail_folder,
-                    presigned_url_endpoint=presigned_url_endpoint,
-                    confirm_upload_endpoint=confirm_upload_endpoint,
-                    json_file_path=json_file_path,
-                    needs_metadata_generation=needs_metadata_generation
+                for attempt in range(max_retries):
+                    try:
+                        progress.update(scan_task, description=f"[cyan]Sending VIDEO data to server for {batch_description}...")
+                        response = requests.post(video_api_endpoint, json=payload, headers=headers)
+                        response.raise_for_status()
+                        response_json = response.json()
+                        break
+                    except requests.exceptions.RequestException as e:
+                        if attempt < max_retries - 1:
+                            print(f"[yellow]API request attempt {attempt + 1}/{max_retries} failed: {str(e)}. Retrying...[/yellow]")
+                            time.sleep(3)
+                        else:
+                            raise
+                
+                if not response_json:
+                    print(f"[red]Failed to get response from server for batch {batch_num+1}[/red]")
+                    continue
+                
+                # Get batch ID
+                batch_id = response_json.get('batch_id')
+                if not batch_id:
+                    print(f"[red]Batch ID not found in response for batch {batch_num+1}[/red]")
+                    continue
+                
+                # Add original data back to items for upload phase
+                for i, item in enumerate(response_json.get('items', [])):
+                    file_name = item['file_name']
+                    # Find original item data
+                    original_item = next((x for x in current_batch if x['file_name'] == file_name), None)
+                    if original_item:
+                        # Add folder path back
+                        item['folder_path'] = original_item['folder_path']
+                        # Add metadata json path if available
+                        if 'meta_data' in original_item:
+                            item['meta_data'] = original_item['meta_data']
+                            # Find the full path to the JSON file
+                            json_name = original_item['meta_data']
+                            json_path = None
+                            for j in json_files:
+                                if os.path.basename(j) == json_name:
+                                    json_path = j
+                                    break
+                            if json_path:
+                                item['json_file_path'] = json_path
+                
+                failed_files = []
+                
+                # Create upload task for this batch
+                upload_task = progress.add_task(
+                    f"[cyan]Uploading files from batch {batch_num+1}/{batch_count}...",
+                    total=len(response_json.get('items', [])) * 2  # *2 for main files and thumbnails
                 )
                 
-                if success:
-                    progress.update(upload_task, description=f"[cyan]Confirming {file_name}")
-                    confirm_success = retry_request(
-                        confirm_upload,
+                # Process each item
+                for item in response_json.get('items', []):
+                    media_id = item['media_id']
+                    file_name = item['file_name']
+                    item_folder_path = item.get('folder_path', folder_path)
+                    
+                    progress.update(upload_task, description=f"[cyan]Uploading {file_name}")
+                    
+                    # Get JSON file path if available
+                    json_file_path = item.get('json_file_path', None)
+                    needs_metadata_generation = not json_file_path
+                    
+                    # Get presigned URLs and upload
+                    success = retry_request(
+                        request_presigned_urls,
                         progress,
                         upload_task,
                         media_id=media_id,
+                        file_name=file_name,
                         token=token,
-                        confirm_upload_endpoint=confirm_upload_endpoint
+                        folder_path=item_folder_path,
+                        thumbnail_folder=thumbnail_folder,
+                        presigned_url_endpoint=presigned_url_endpoint,
+                        confirm_upload_endpoint=confirm_upload_endpoint,
+                        json_file_path=json_file_path,
+                        needs_metadata_generation=needs_metadata_generation
                     )
-                    if not confirm_success:
+                    
+                    if success:
+                        progress.update(upload_task, description=f"[cyan]Confirming {file_name}")
+                        confirm_success = retry_request(
+                            confirm_upload,
+                            progress,
+                            upload_task,
+                            media_id=media_id,
+                            token=token,
+                            confirm_upload_endpoint=confirm_upload_endpoint
+                        )
+                        if not confirm_success:
+                            failed_files.append(file_name)
+                    else:
                         failed_files.append(file_name)
-                else:
-                    failed_files.append(file_name)
+                    
+                    progress.advance(upload_task, 2)
                 
-                progress.advance(upload_task, 2)
-            
-            # Log any failed files
-            if failed_files:
-                print(f"[yellow]Warning: {len(failed_files)} files failed in folder {folder_name}[/yellow]")
-                print(f"[yellow]Failed files: {', '.join(failed_files[:5])}{'...' if len(failed_files) > 5 else ''}[/yellow]")
-            
-            # Confirm the batch
-            if confirm_batch_upload(batch_id, token, batch_confirm_endpoint):
-                print(f"[green]Folder {folder_name} processed successfully![/green]")
-                return True
-            else:
-                print(f"[red]Folder {folder_name} had confirmation errors[/red]")
-                return False
-            
-        except Exception as e:
-            print(f"[red]Error during upload process for folder {folder_name}: {str(e)}[/red]")
-            return False
+                # Log any failed files
+                if failed_files:
+                    print(f"[yellow]Warning: {len(failed_files)} files failed in batch {batch_num+1}[/yellow]")
+                    print(f"[yellow]Failed files: {', '.join(failed_files[:5])}{'...' if len(failed_files) > 5 else ''}[/yellow]")
+                
+                # Confirm the batch
+                if confirm_batch_upload(batch_id, token, batch_confirm_endpoint):
+                    print(f"[green]Batch {batch_num+1}/{batch_count} processed successfully![/green]")
+                    successful_batches += 1
+                else:
+                    print(f"[red]Batch {batch_num+1}/{batch_count} had confirmation errors[/red]")
+                
+                # Add a delay between batches to let server process
+                if batch_num < batch_count - 1:
+                    delay_time = 5  # 5 seconds between batches
+                    print(f"[yellow]Waiting {delay_time} seconds before processing next batch...[/yellow]")
+                    time.sleep(delay_time)
+                
+            except Exception as e:
+                print(f"[red]Error during upload process for batch {batch_num+1}: {str(e)}[/red]")
+        
+        # Final status
+        if successful_batches == batch_count:
+            print(f"[green]All {batch_count} batches in folder {folder_name} processed successfully![/green]")
+            return True
+        else:
+            print(f"[yellow]Some batches had errors: {successful_batches}/{batch_count} successful[/yellow]")
+            return successful_batches > 0  # Return True if at least one batch was successful
         
 def request_presigned_urls(media_id, file_name, token, folder_path, thumbnail_folder, presigned_url_endpoint, 
                           confirm_upload_endpoint, json_file_path=None, needs_metadata_generation=False):
