@@ -10,6 +10,7 @@ import argparse
 from tqdm import tqdm, trange
 import cv2
 import math
+from tabulate import tabulate  # Added for summary table
 import builtins
 import datetime
 
@@ -716,8 +717,8 @@ def print_upload_summary():
     
     # Print the table
     headers = ["Filename", "", "Status", "Details"]
-    #print(tabulate(table_data, headers=headers, tablefmt="grid"))
-    #print("="*80)
+    print(tabulate(table_data, headers=headers, tablefmt="grid"))
+    print("="*80)
 
 def main():
     """Main function to handle command line arguments"""
@@ -855,4 +856,4 @@ def process_directory_structure(base_url, token, project_id, input_path):
         print(f"  - {name}")
 
     builtins.print = original_print  # Restore original print
-    return True
+    return True
\ No newline at end of file
